"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def decode(hub, ctx, encoded_message: str) -> Dict:
    r"""
    **Autogenerated function**

    Decodes additional information about the authorization status of a request from an encoded message returned in response to an Amazon Web Services request. For example, if a user is not authorized to perform an operation that he or she has requested, the request returns a Client.UnauthorizedOperation response (an HTTP 403 response). Some Amazon Web Services operations additionally return an encoded message that can provide details about this authorization failure.   Only certain Amazon Web Services operations return an encoded authorization message. The documentation for an individual operation indicates whether that operation returns an encoded message in addition to returning an HTTP code.  The message is encoded because the details of the authorization status can constitute privileged information that the user who requested the operation should not see. To decode an authorization status message, a user must be granted permissions via an IAM policy to request the DecodeAuthorizationMessage (sts:DecodeAuthorizationMessage) action.  The decoded message includes the following type of information:   Whether the request was denied due to an explicit deny or due to the absence of an explicit allow. For more information, see Determining Whether a Request is Allowed or Denied in the IAM User Guide.    The principal who made the request.   The requested action.   The requested resource.   The values of condition keys in the context of the user's request.

    Args:
        encoded_message(str): The encoded message that was returned with the response.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sts.authorization_message.decode(ctx, encoded_message=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sts.authorization_message.decode encoded_message=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sts",
        operation="decode_authorization_message",
        op_kwargs={"EncodedMessage": encoded_message},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


__func_alias__ = {"set_": "set"}


async def set_(
    hub,
    ctx,
    alarm_name: str,
    state_value: str,
    state_reason: str,
    state_reason_data: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Temporarily sets the state of an alarm for testing purposes. When the updated state differs from the previous value, the action configured for the appropriate state is invoked. For example, if your alarm is configured to send an Amazon SNS message when an alarm is triggered, temporarily changing the alarm state to ALARM sends an SNS message. Metric alarms returns to their actual state quickly, often within seconds. Because the metric alarm state change happens quickly, it is typically only visible in the alarm's History tab in the Amazon CloudWatch console or through DescribeAlarmHistory. If you use SetAlarmState on a composite alarm, the composite alarm is not guaranteed to return to its actual state. It returns to its actual state only once any of its children alarms change state. It is also reevaluated if you update its configuration. If an alarm triggers EC2 Auto Scaling policies or application Auto Scaling policies, you must include information in the StateReasonData parameter to enable the policy to take the correct action.

    Args:
        alarm_name(str): The name of the alarm.
        state_value(str): The value of the state.
        state_reason(str): The reason that this alarm is set to this specific state, in text format.
        state_reason_data(str, optional): The reason that this alarm is set to this specific state, in JSON format. For SNS or EC2 alarm actions, this is just informational. But for EC2 Auto Scaling or application Auto Scaling alarm actions, the Auto Scaling policy uses the information in this field to take the correct action. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.alarm.state.set(
                ctx, alarm_name=value, state_value=value, state_reason=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.alarm.state.set alarm_name=value, state_value=value, state_reason=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="set_alarm_state",
        op_kwargs={
            "AlarmName": alarm_name,
            "StateValue": state_value,
            "StateReason": state_reason,
            "StateReasonData": state_reason_data,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, identity: str, notification_type: str, enabled: bool) -> Dict:
    r"""
    **Autogenerated function**

    Given an identity (an email address or a domain), sets whether Amazon SES includes the original email headers in the Amazon Simple Notification Service (Amazon SNS) notifications of a specified type. You can execute this operation no more than once per second. For more information about using notifications with Amazon SES, see the Amazon SES Developer Guide.

    Args:
        identity(str): The identity for which to enable or disable headers in notifications. Examples: user@example.com, example.com.
        notification_type(str): The notification type for which to enable or disable headers in notifications. .
        enabled(bool): Sets whether Amazon SES includes the original email headers in Amazon SNS notifications of the specified notification type. A value of true specifies that Amazon SES will include headers in notifications, and a value of false specifies that Amazon SES will not include headers in notifications. This value can only be set when NotificationType is already set to use a particular Amazon SNS topic.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.identity.header_in_notification_enabled.set(
                ctx, identity=value, notification_type=value, enabled=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.identity.header_in_notification_enabled.set identity=value, notification_type=value, enabled=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="set_identity_headers_in_notifications_enabled",
        op_kwargs={
            "Identity": identity,
            "NotificationType": notification_type,
            "Enabled": enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, type_: str, export_config: Dict, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a report group. A report group contains a collection of reports.

    Args:
        name(str):  The name of the report group. .
        type_(str):  The type of report group. .
        export_config(Dict):  A ReportExportConfig object that contains information about where the report group test results are exported. .
        tags(List, optional):  A list of tag key and value pairs associated with this report group.  These tags are available for use by AWS services that support AWS CodeBuild report group tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.report.group.init.create(
                ctx, name=value, type_=value, export_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.report.group.init.create name=value, type_=value, export_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="create_report_group",
        op_kwargs={
            "name": name,
            "type": type_,
            "exportConfig": export_config,
            "tags": tags,
        },
    )


async def delete(hub, ctx, arn: str, delete_reports: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a report group. Before you delete a report group, you must delete its reports.

    Args:
        arn(str): The ARN of the report group to delete. .
        delete_reports(bool, optional): If true, deletes any reports that belong to a report group before deleting the report group.  If false, you must delete any reports in the report group. Use ListReportsForReportGroup to get the reports in a report group. Use DeleteReport to delete the reports. If you call DeleteReportGroup for a report group that contains one or more reports, an exception is thrown. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.report.group.init.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.report.group.init.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="delete_report_group",
        op_kwargs={"arn": arn, "deleteReports": delete_reports},
    )


async def list_all(
    hub,
    ctx,
    sort_order: str = None,
    sort_by: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Gets a list ARNs for the report groups in the current AWS account.

    Args:
        sort_order(str, optional):  Used to specify the order to sort the list of returned report groups. Valid values are ASCENDING and DESCENDING. . Defaults to None.
        sort_by(str, optional):  The criterion to be used to list build report groups. Valid values include:     CREATED_TIME: List based on when each report group was created.    LAST_MODIFIED_TIME: List based on when each report group was last changed.    NAME: List based on each report group's name.  . Defaults to None.
        next_token(str, optional):  During a previous call, the maximum number of items that can be returned is the value specified in maxResults. If there more items in the list, then a unique string called a nextToken is returned. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned. . Defaults to None.
        max_results(int, optional):  The maximum number of paginated report groups returned per response. Use nextToken to iterate pages in the list of returned ReportGroup objects. The default value is 100. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.report.group.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.report.group.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="list_report_groups",
        op_kwargs={
            "sortOrder": sort_order,
            "sortBy": sort_by,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub, ctx, arn: str, export_config: Dict = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

     Updates a report group.

    Args:
        arn(str):  The ARN of the report group to update. .
        export_config(Dict, optional):  Used to specify an updated export type. Valid values are:     S3: The report results are exported to an S3 bucket.     NO_EXPORT: The report results are not exported.   . Defaults to None.
        tags(List, optional):  An updated list of tag key and value pairs associated with this report group.  These tags are available for use by AWS services that support AWS CodeBuild report group tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.report.group.init.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.report.group.init.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="update_report_group",
        op_kwargs={"arn": arn, "exportConfig": export_config, "tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, device_arn: str, network_profile_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates a device with the specified network profile.

    Args:
        device_arn(str): The device ARN.
        network_profile_arn(str): The ARN of the network profile to associate with a device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.device.with_.network_profile.associate(
                ctx, device_arn=value, network_profile_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.device.with_.network_profile.associate device_arn=value, network_profile_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="associate_device_with_network_profile",
        op_kwargs={"DeviceArn": device_arn, "NetworkProfileArn": network_profile_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    instance_profile_name: str,
    client_token: str,
    description: str = None,
    instance_types: List = None,
    security_group_ids: List = None,
    subnet_id: str = None,
    logging: Dict = None,
    key_pair: str = None,
    terminate_instance_on_failure: bool = None,
    sns_topic_arn: str = None,
    resource_tags: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new infrastructure configuration. An infrastructure configuration defines the environment in which your image will be built and tested.

    Args:
        name(str): The name of the infrastructure configuration.
        description(str, optional): The description of the infrastructure configuration. Defaults to None.
        instance_types(List, optional): The instance types of the infrastructure configuration. You can specify one or more instance types to use for this build. The service will pick one of these instance types based on availability. Defaults to None.
        instance_profile_name(str): The instance profile to associate with the instance used to customize your Amazon EC2 AMI.
        security_group_ids(List, optional): The security group IDs to associate with the instance used to customize your Amazon EC2 AMI. Defaults to None.
        subnet_id(str, optional): The subnet ID in which to place the instance used to customize your Amazon EC2 AMI. Defaults to None.
        logging(Dict, optional): The logging configuration of the infrastructure configuration. Defaults to None.
        key_pair(str, optional): The key pair of the infrastructure configuration. This can be used to log on to and debug the instance used to create your image. Defaults to None.
        terminate_instance_on_failure(bool, optional): The terminate instance on failure setting of the infrastructure configuration. Set to false if you want Image Builder to retain the instance used to configure your AMI if the build or test phase of your workflow fails. Defaults to None.
        sns_topic_arn(str, optional): The SNS topic on which to send image build events. Defaults to None.
        resource_tags(Dict, optional): The tags attached to the resource created by Image Builder. Defaults to None.
        tags(Dict, optional): The tags of the infrastructure configuration. Defaults to None.
        client_token(str): The idempotency token used to make this request idempotent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.infrastructure_configuration.create(
                ctx, name=value, instance_profile_name=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.infrastructure_configuration.create name=value, instance_profile_name=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="create_infrastructure_configuration",
        op_kwargs={
            "name": name,
            "description": description,
            "instanceTypes": instance_types,
            "instanceProfileName": instance_profile_name,
            "securityGroupIds": security_group_ids,
            "subnetId": subnet_id,
            "logging": logging,
            "keyPair": key_pair,
            "terminateInstanceOnFailure": terminate_instance_on_failure,
            "snsTopicArn": sns_topic_arn,
            "resourceTags": resource_tags,
            "tags": tags,
            "clientToken": client_token,
        },
    )


async def delete(hub, ctx, infrastructure_configuration_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes an infrastructure configuration.

    Args:
        infrastructure_configuration_arn(str): The Amazon Resource Name (ARN) of the infrastructure configuration to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.infrastructure_configuration.delete(
                ctx, infrastructure_configuration_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.infrastructure_configuration.delete infrastructure_configuration_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="delete_infrastructure_configuration",
        op_kwargs={"infrastructureConfigurationArn": infrastructure_configuration_arn},
    )


async def get(hub, ctx, infrastructure_configuration_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets an infrastructure configuration.

    Args:
        infrastructure_configuration_arn(str): The Amazon Resource Name (ARN) of the infrastructure configuration that you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.infrastructure_configuration.get(
                ctx, infrastructure_configuration_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.infrastructure_configuration.get infrastructure_configuration_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="get_infrastructure_configuration",
        op_kwargs={"infrastructureConfigurationArn": infrastructure_configuration_arn},
    )


async def list_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of infrastructure configurations.

    Args:
        filters(List, optional): The filters. Defaults to None.
        max_results(int, optional): The maximum items to return in a request. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. This is the NextToken from a previously truncated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.infrastructure_configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.infrastructure_configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="list_infrastructure_configurations",
        op_kwargs={
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    infrastructure_configuration_arn: str,
    instance_profile_name: str,
    client_token: str,
    description: str = None,
    instance_types: List = None,
    security_group_ids: List = None,
    subnet_id: str = None,
    logging: Dict = None,
    key_pair: str = None,
    terminate_instance_on_failure: bool = None,
    sns_topic_arn: str = None,
    resource_tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates a new infrastructure configuration. An infrastructure configuration defines the environment in which your image will be built and tested.

    Args:
        infrastructure_configuration_arn(str): The Amazon Resource Name (ARN) of the infrastructure configuration that you want to update.
        description(str, optional): The description of the infrastructure configuration. Defaults to None.
        instance_types(List, optional): The instance types of the infrastructure configuration. You can specify one or more instance types to use for this build. The service will pick one of these instance types based on availability. Defaults to None.
        instance_profile_name(str): The instance profile to associate with the instance used to customize your Amazon EC2 AMI.
        security_group_ids(List, optional): The security group IDs to associate with the instance used to customize your Amazon EC2 AMI. Defaults to None.
        subnet_id(str, optional): The subnet ID to place the instance used to customize your Amazon EC2 AMI in. Defaults to None.
        logging(Dict, optional): The logging configuration of the infrastructure configuration. Defaults to None.
        key_pair(str, optional): The key pair of the infrastructure configuration. This can be used to log on to and debug the instance used to create your image. Defaults to None.
        terminate_instance_on_failure(bool, optional): The terminate instance on failure setting of the infrastructure configuration. Set to false if you want Image Builder to retain the instance used to configure your AMI if the build or test phase of your workflow fails. Defaults to None.
        sns_topic_arn(str, optional): The SNS topic on which to send image build events. Defaults to None.
        client_token(str): The idempotency token used to make this request idempotent.
        resource_tags(Dict, optional): The tags attached to the resource created by Image Builder. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.infrastructure_configuration.update(
                ctx,
                infrastructure_configuration_arn=value,
                instance_profile_name=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.infrastructure_configuration.update infrastructure_configuration_arn=value, instance_profile_name=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="update_infrastructure_configuration",
        op_kwargs={
            "infrastructureConfigurationArn": infrastructure_configuration_arn,
            "description": description,
            "instanceTypes": instance_types,
            "instanceProfileName": instance_profile_name,
            "securityGroupIds": security_group_ids,
            "subnetId": subnet_id,
            "logging": logging,
            "keyPair": key_pair,
            "terminateInstanceOnFailure": terminate_instance_on_failure,
            "snsTopicArn": sns_topic_arn,
            "clientToken": client_token,
            "resourceTags": resource_tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, vpc_id: str, dry_run: bool = None, tag_specifications: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a network ACL in a VPC. Network ACLs provide an optional layer of security (in addition to security groups) for the instances in your VPC. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        vpc_id(str): The ID of the VPC.
        tag_specifications(List, optional): The tags to assign to the network ACL. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.acl.init.create(ctx, vpc_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.acl.init.create vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_network_acl",
        op_kwargs={
            "DryRun": dry_run,
            "VpcId": vpc_id,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete(hub, ctx, network_acl_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified network ACL. You can't delete the ACL if it's associated with any subnets. You can't delete the default network ACL.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        network_acl_id(str): The ID of the network ACL.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.acl.init.delete(ctx, network_acl_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.acl.init.delete network_acl_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_network_acl",
        op_kwargs={"DryRun": dry_run, "NetworkAclId": network_acl_id},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    dry_run: bool = None,
    network_acl_ids: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your network ACLs. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide.

    Args:
        filters(List, optional): One or more filters.    association.association-id - The ID of an association ID for the ACL.    association.network-acl-id - The ID of the network ACL involved in the association.    association.subnet-id - The ID of the subnet involved in the association.    default - Indicates whether the ACL is the default network ACL for the VPC.    entry.cidr - The IPv4 CIDR range specified in the entry.    entry.icmp.code - The ICMP code specified in the entry, if any.    entry.icmp.type - The ICMP type specified in the entry, if any.    entry.ipv6-cidr - The IPv6 CIDR range specified in the entry.    entry.port-range.from - The start of the port range specified in the entry.     entry.port-range.to - The end of the port range specified in the entry.     entry.protocol - The protocol specified in the entry (tcp | udp | icmp or a protocol number).    entry.rule-action - Allows or denies the matching traffic (allow | deny).    entry.rule-number - The number of an entry (in other words, rule) in the set of ACL entries.    network-acl-id - The ID of the network ACL.    owner-id - The ID of the Amazon Web Services account that owns the network ACL.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC for the network ACL.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        network_acl_ids(List, optional): One or more network ACL IDs. Default: Describes all your network ACLs. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.acl.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.acl.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_network_acls",
        op_kwargs={
            "Filters": filters,
            "DryRun": dry_run,
            "NetworkAclIds": network_acl_ids,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    type_: str,
    destination_name: str,
    name: str = None,
    description: str = None,
    client_request_token: str = None,
    lo_ra_wan: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provisions a wireless device.

    Args:
        type_(str): The wireless device type.
        name(str, optional): The name of the new resource. Defaults to None.
        description(str, optional): The description of the new resource. Defaults to None.
        destination_name(str): The name of the destination to assign to the new wireless device.
        client_request_token(str, optional): Each resource must have a unique client request token. If you try to create a new resource with the same token as a resource that already exists, an exception occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. . Defaults to None.
        lo_ra_wan(Dict, optional): The device configuration information to use to create the wireless device. Defaults to None.
        tags(List, optional): The tags to attach to the new wireless device. Tags are metadata that you can use to manage a resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.device.init.create(
                ctx, type_=value, destination_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.device.init.create type_=value, destination_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="create_wireless_device",
        op_kwargs={
            "Type": type_,
            "Name": name,
            "Description": description,
            "DestinationName": destination_name,
            "ClientRequestToken": client_request_token,
            "LoRaWAN": lo_ra_wan,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a wireless device.

    Args:
        id_(str): The ID of the resource to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.device.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.device.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="delete_wireless_device",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, identifier: str, identifier_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a wireless device.

    Args:
        identifier(str): The identifier of the wireless device to get.
        identifier_type(str): The type of identifier used in identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.device.init.get(
                ctx, identifier=value, identifier_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.device.init.get identifier=value, identifier_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_wireless_device",
        op_kwargs={"Identifier": identifier, "IdentifierType": identifier_type},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    destination_name: str = None,
    device_profile_id: str = None,
    service_profile_id: str = None,
    wireless_device_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the wireless devices registered to your AWS account.

    Args:
        max_results(int, optional): The maximum number of results to return in this operation. Defaults to None.
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        destination_name(str, optional): A filter to list only the wireless devices that use this destination. Defaults to None.
        device_profile_id(str, optional): A filter to list only the wireless devices that use this device profile. Defaults to None.
        service_profile_id(str, optional): A filter to list only the wireless devices that use this service profile. Defaults to None.
        wireless_device_type(str, optional): A filter to list only the wireless devices that use this wireless device type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.device.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.device.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="list_wireless_devices",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "DestinationName": destination_name,
            "DeviceProfileId": device_profile_id,
            "ServiceProfileId": service_profile_id,
            "WirelessDeviceType": wireless_device_type,
        },
    )


async def test(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Simulates a provisioned device by sending an uplink data payload of Hello.

    Args:
        id_(str): The ID of the wireless device to test.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.device.init.test(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.device.init.test id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="test_wireless_device",
        op_kwargs={"Id": id_},
    )


async def update(
    hub,
    ctx,
    id_: str,
    destination_name: str = None,
    name: str = None,
    description: str = None,
    lo_ra_wan: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates properties of a wireless device.

    Args:
        id_(str): The ID of the resource to update.
        destination_name(str, optional): The name of the new destination for the device. Defaults to None.
        name(str, optional): The new name of the resource. Defaults to None.
        description(str, optional): A new description of the resource. Defaults to None.
        lo_ra_wan(Dict, optional): The updated wireless device's configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.device.init.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.device.init.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="update_wireless_device",
        op_kwargs={
            "Id": id_,
            "DestinationName": destination_name,
            "Name": name,
            "Description": description,
            "LoRaWAN": lo_ra_wan,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def detach(hub, ctx, load_balancer_name: str, subnets: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified subnets from the set of configured subnets for the load balancer. After a subnet is removed, all EC2 instances registered with the load balancer in the removed subnet go into the OutOfService state. Then, the load balancer balances the traffic among the remaining routable subnets.

    Args:
        load_balancer_name(str): The name of the load balancer.
        subnets(List): The IDs of the subnets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.from_subnet.detach(
                ctx, load_balancer_name=value, subnets=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.from_subnet.detach load_balancer_name=value, subnets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="detach_load_balancer_from_subnets",
        op_kwargs={"LoadBalancerName": load_balancer_name, "Subnets": subnets},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def initiate(
    hub,
    ctx,
    auth_flow: str,
    client_id: str,
    auth_parameters: Dict = None,
    client_metadata: Dict = None,
    analytics_metadata: Dict = None,
    user_context_data: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Initiates the authentication flow.  This action might generate an SMS text message. Starting June 1, 2021, U.S. telecom carriers require that you register an origination phone number before you can send SMS messages to U.S. phone numbers. If you use SMS text messages in Amazon Cognito, you must register a phone number with Amazon Pinpoint. Cognito will use the the registered number automatically. Otherwise, Cognito users that must receive SMS messages might be unable to sign up, activate their accounts, or sign in. If you have never used SMS text messages with Amazon Cognito or any other Amazon Web Service, Amazon SNS might place your account in SMS sandbox. In  sandbox mode , you’ll have limitations, such as sending messages to only verified phone numbers. After testing in the sandbox environment, you can move out of the SMS sandbox and into production. For more information, see  SMS message settings for Cognito User Pools in the Amazon Cognito Developer Guide.

    Args:
        auth_flow(str): The authentication flow for this call to execute. The API action will depend on this value. For example:     REFRESH_TOKEN_AUTH will take in a valid refresh token and return new tokens.    USER_SRP_AUTH will take in USERNAME and SRP_A and return the SRP variables to be used for next challenge execution.    USER_PASSWORD_AUTH will take in USERNAME and PASSWORD and return the next challenge or tokens.   Valid values include:    USER_SRP_AUTH: Authentication flow for the Secure Remote Password (SRP) protocol.    REFRESH_TOKEN_AUTH/REFRESH_TOKEN: Authentication flow for refreshing the access token and ID token by supplying a valid refresh token.    CUSTOM_AUTH: Custom authentication flow.    USER_PASSWORD_AUTH: Non-SRP authentication flow; USERNAME and PASSWORD are passed directly. If a user migration Lambda trigger is set, this flow will invoke the user migration Lambda if the USERNAME is not found in the user pool.     ADMIN_USER_PASSWORD_AUTH: Admin-based user password authentication. This replaces the ADMIN_NO_SRP_AUTH authentication flow. In this flow, Cognito receives the password in the request instead of using the SRP process to verify passwords.    ADMIN_NO_SRP_AUTH is not a valid value.
        auth_parameters(Dict, optional): The authentication parameters. These are inputs corresponding to the AuthFlow that you are invoking. The required values depend on the value of AuthFlow:   For USER_SRP_AUTH: USERNAME (required), SRP_A (required), SECRET_HASH (required if the app client is configured with a client secret), DEVICE_KEY.   For REFRESH_TOKEN_AUTH/REFRESH_TOKEN: REFRESH_TOKEN (required), SECRET_HASH (required if the app client is configured with a client secret), DEVICE_KEY.   For CUSTOM_AUTH: USERNAME (required), SECRET_HASH (if app client is configured with client secret), DEVICE_KEY. To start the authentication flow with password verification, include ChallengeName: SRP_A and SRP_A: (The SRP_A Value).  . Defaults to None.
        client_metadata(Dict, optional): A map of custom key-value pairs that you can provide as input for certain custom workflows that this action triggers. You create custom workflows by assigning Lambda functions to user pool triggers. When you use the InitiateAuth API action, Amazon Cognito invokes the Lambda functions that are specified for various triggers. The ClientMetadata value is passed as input to the functions for only the following triggers:   Pre signup   Pre authentication   User migration   When Amazon Cognito invokes the functions for these triggers, it passes a JSON payload, which the function receives as input. This payload contains a validationData attribute, which provides the data that you assigned to the ClientMetadata parameter in your InitiateAuth request. In your function code in Lambda, you can process the validationData value to enhance your workflow for your specific needs. When you use the InitiateAuth API action, Amazon Cognito also invokes the functions for the following triggers, but it does not provide the ClientMetadata value as input:   Post authentication   Custom message   Pre token generation   Create auth challenge   Define auth challenge   Verify auth challenge   For more information, see Customizing User Pool Workflows with Lambda Triggers in the Amazon Cognito Developer Guide.  Take the following limitations into consideration when you use the ClientMetadata parameter:   Amazon Cognito does not store the ClientMetadata value. This data is available only to Lambda triggers that are assigned to a user pool to support custom workflows. If your user pool configuration does not include triggers, the ClientMetadata parameter serves no purpose.   Amazon Cognito does not validate the ClientMetadata value.   Amazon Cognito does not encrypt the the ClientMetadata value, so don't use it to provide sensitive information.   . Defaults to None.
        client_id(str): The app client ID.
        analytics_metadata(Dict, optional): The Amazon Pinpoint analytics metadata for collecting metrics for InitiateAuth calls. Defaults to None.
        user_context_data(Dict, optional): Contextual data such as the user's device fingerprint, IP address, or location used for evaluating the risk of an unexpected event by Amazon Cognito advanced security. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.auth.init.initiate(
                ctx, auth_flow=value, client_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.auth.init.initiate auth_flow=value, client_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="initiate_auth",
        op_kwargs={
            "AuthFlow": auth_flow,
            "AuthParameters": auth_parameters,
            "ClientMetadata": client_metadata,
            "ClientId": client_id,
            "AnalyticsMetadata": analytics_metadata,
            "UserContextData": user_context_data,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, container_instance: str, cluster: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Amazon ECS container agent on a specified container instance. Updating the Amazon ECS container agent does not interrupt running tasks or services on the container instance. The process for updating the agent differs depending on whether your container instance was launched with the Amazon ECS-optimized AMI or another operating system.  The UpdateContainerAgent API isn't supported for container instances using the Amazon ECS-optimized Amazon Linux 2 (arm64) AMI. To update the container agent, you can update the ecs-init package which will update the agent. For more information, see Updating the Amazon ECS container agent in the Amazon Elastic Container Service Developer Guide.  The UpdateContainerAgent API requires an Amazon ECS-optimized AMI or Amazon Linux AMI with the ecs-init service installed and running. For help updating the Amazon ECS container agent on other operating systems, see Manually updating the Amazon ECS container agent in the Amazon Elastic Container Service Developer Guide.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster that your container instance is running on. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        container_instance(str): The container instance ID or full ARN entries for the container instance on which you would like to update the Amazon ECS container agent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.container.agent.update(ctx, container_instance=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.container.agent.update container_instance=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="update_container_agent",
        op_kwargs={"cluster": cluster, "containerInstance": container_instance},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    data_source_id: str,
    data_spec: Dict,
    data_source_name: str = None,
    compute_statistics: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a DataSource object. A DataSource references data that can be used to perform CreateMLModel, CreateEvaluation, or CreateBatchPrediction operations.  CreateDataSourceFromS3 is an asynchronous operation. In response to CreateDataSourceFromS3, Amazon Machine Learning (Amazon ML) immediately returns and sets the DataSource status to PENDING. After the DataSource has been created and is ready for use, Amazon ML sets the Status parameter to COMPLETED. DataSource in the COMPLETED or PENDING state can be used to perform only CreateMLModel, CreateEvaluation or CreateBatchPrediction operations.   If Amazon ML can't accept the input source, it sets the Status parameter to FAILED and includes an error message in the Message attribute of the GetDataSource operation response.  The observation data used in a DataSource should be ready to use; that is, it should have a consistent structure, and missing data values should be kept to a minimum. The observation data must reside in one or more .csv files in an Amazon Simple Storage Service (Amazon S3) location, along with a schema that describes the data items by name and type. The same schema must be used for all of the data files referenced by the DataSource.  After the DataSource has been created, it's ready to use in evaluations and batch predictions. If you plan to use the DataSource to train an MLModel, the DataSource also needs a recipe. A recipe describes how each input variable will be used in training an MLModel. Will the variable be included or excluded from training? Will the variable be manipulated; for example, will it be combined with another variable or will it be split apart into word combinations? The recipe provides answers to these questions.

    Args:
        data_source_id(str): A user-supplied identifier that uniquely identifies the DataSource. .
        data_source_name(str, optional): A user-supplied name or description of the DataSource. . Defaults to None.
        data_spec(Dict): The data specification of a DataSource:   DataLocationS3 - The Amazon S3 location of the observation data.   DataSchemaLocationS3 - The Amazon S3 location of the DataSchema.   DataSchema - A JSON string representing the schema. This is not required if DataSchemaUri is specified.    DataRearrangement - A JSON string that represents the splitting and rearrangement requirements for the Datasource.   Sample -  "{\"splitting\":{\"percentBegin\":10,\"percentEnd\":60}}"   .
        compute_statistics(bool, optional): The compute statistics for a DataSource. The statistics are generated from the observation data referenced by a DataSource. Amazon ML uses the statistics internally during MLModel training. This parameter must be set to true if the DataSource needs to be used for MLModel training. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.data_source.from_.s3.create(
                ctx, data_source_id=value, data_spec=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.data_source.from_.s3.create data_source_id=value, data_spec=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="create_data_source_from_s3",
        op_kwargs={
            "DataSourceId": data_source_id,
            "DataSourceName": data_source_name,
            "DataSpec": data_spec,
            "ComputeStatistics": compute_statistics,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def connect(hub, ctx, custom_key_store_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Connects or reconnects a custom key store to its associated AWS CloudHSM cluster. The custom key store must be connected before you can create customer master keys (CMKs) in the key store or use the CMKs it contains. You can disconnect and reconnect a custom key store at any time. To connect a custom key store, its associated AWS CloudHSM cluster must have at least one active HSM. To get the number of active HSMs in a cluster, use the DescribeClusters operation. To add HSMs to the cluster, use the CreateHsm operation. Also, the  kmsuser crypto user (CU) must not be logged into the cluster. This prevents AWS KMS from using this account to log in. The connection process can take an extended amount of time to complete; up to 20 minutes. This operation starts the connection process, but it does not wait for it to complete. When it succeeds, this operation quickly returns an HTTP 200 response and a JSON object with no properties. However, this response does not indicate that the custom key store is connected. To get the connection state of the custom key store, use the DescribeCustomKeyStores operation. During the connection process, AWS KMS finds the AWS CloudHSM cluster that is associated with the custom key store, creates the connection infrastructure, connects to the cluster, logs into the AWS CloudHSM client as the kmsuser CU, and rotates its password. The ConnectCustomKeyStore operation might fail for various reasons. To find the reason, use the DescribeCustomKeyStores operation and see the ConnectionErrorCode in the response. For help interpreting the ConnectionErrorCode, see CustomKeyStoresListEntry. To fix the failure, use the DisconnectCustomKeyStore operation to disconnect the custom key store, correct the error, use the UpdateCustomKeyStore operation if necessary, and then use ConnectCustomKeyStore again. If you are having trouble connecting or disconnecting a custom key store, see Troubleshooting a Custom Key Store in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a custom key store in a different AWS account.  Required permissions: kms:ConnectCustomKeyStore (IAM policy)  Related operations     CreateCustomKeyStore     DeleteCustomKeyStore     DescribeCustomKeyStores     DisconnectCustomKeyStore     UpdateCustomKeyStore

    Args:
        custom_key_store_id(str): Enter the key store ID of the custom key store that you want to connect. To find the ID of a custom key store, use the DescribeCustomKeyStores operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.custom_key_store.connect(ctx, custom_key_store_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.custom_key_store.connect custom_key_store_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="connect_custom_key_store",
        op_kwargs={"CustomKeyStoreId": custom_key_store_id},
    )


async def create(
    hub,
    ctx,
    custom_key_store_name: str,
    cloud_hsm_cluster_id: str,
    trust_anchor_certificate: str,
    key_store_password: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a custom key store that is associated with an AWS CloudHSM cluster that you own and manage. This operation is part of the Custom Key Store feature feature in AWS KMS, which combines the convenience and extensive integration of AWS KMS with the isolation and control of a single-tenant key store. Before you create the custom key store, you must assemble the required elements, including an AWS CloudHSM cluster that fulfills the requirements for a custom key store. For details about the required elements, see Assemble the Prerequisites in the AWS Key Management Service Developer Guide. When the operation completes successfully, it returns the ID of the new custom key store. Before you can use your new custom key store, you need to use the ConnectCustomKeyStore operation to connect the new key store to its AWS CloudHSM cluster. Even if you are not going to use your custom key store immediately, you might want to connect it to verify that all settings are correct and then disconnect it until you are ready to use it. For help with failures, see Troubleshooting a Custom Key Store in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a custom key store in a different AWS account.  Required permissions: kms:CreateCustomKeyStore (IAM policy).  Related operations:     ConnectCustomKeyStore     DeleteCustomKeyStore     DescribeCustomKeyStores     DisconnectCustomKeyStore     UpdateCustomKeyStore

    Args:
        custom_key_store_name(str): Specifies a friendly name for the custom key store. The name must be unique in your AWS account.
        cloud_hsm_cluster_id(str): Identifies the AWS CloudHSM cluster for the custom key store. Enter the cluster ID of any active AWS CloudHSM cluster that is not already associated with a custom key store. To find the cluster ID, use the DescribeClusters operation.
        trust_anchor_certificate(str): Enter the content of the trust anchor certificate for the cluster. This is the content of the customerCA.crt file that you created when you initialized the cluster.
        key_store_password(str): Enter the password of the  kmsuser crypto user (CU) account in the specified AWS CloudHSM cluster. AWS KMS logs into the cluster as this user to manage key material on your behalf. The password must be a string of 7 to 32 characters. Its value is case sensitive. This parameter tells AWS KMS the kmsuser account password; it does not change the password in the AWS CloudHSM cluster.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.custom_key_store.create(
                ctx,
                custom_key_store_name=value,
                cloud_hsm_cluster_id=value,
                trust_anchor_certificate=value,
                key_store_password=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.custom_key_store.create custom_key_store_name=value, cloud_hsm_cluster_id=value, trust_anchor_certificate=value, key_store_password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="create_custom_key_store",
        op_kwargs={
            "CustomKeyStoreName": custom_key_store_name,
            "CloudHsmClusterId": cloud_hsm_cluster_id,
            "TrustAnchorCertificate": trust_anchor_certificate,
            "KeyStorePassword": key_store_password,
        },
    )


async def delete(hub, ctx, custom_key_store_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a custom key store. This operation does not delete the AWS CloudHSM cluster that is associated with the custom key store, or affect any users or keys in the cluster. The custom key store that you delete cannot contain any AWS KMS customer master keys (CMKs). Before deleting the key store, verify that you will never need to use any of the CMKs in the key store for any cryptographic operations. Then, use ScheduleKeyDeletion to delete the AWS KMS customer master keys (CMKs) from the key store. When the scheduled waiting period expires, the ScheduleKeyDeletion operation deletes the CMKs. Then it makes a best effort to delete the key material from the associated cluster. However, you might need to manually delete the orphaned key material from the cluster and its backups. After all CMKs are deleted from AWS KMS, use DisconnectCustomKeyStore to disconnect the key store from AWS KMS. Then, you can delete the custom key store. Instead of deleting the custom key store, consider using DisconnectCustomKeyStore to disconnect it from AWS KMS. While the key store is disconnected, you cannot create or use the CMKs in the key store. But, you do not need to delete CMKs and you can reconnect a disconnected custom key store at any time. If the operation succeeds, it returns a JSON object with no properties. This operation is part of the Custom Key Store feature feature in AWS KMS, which combines the convenience and extensive integration of AWS KMS with the isolation and control of a single-tenant key store.  Cross-account use: No. You cannot perform this operation on a custom key store in a different AWS account.  Required permissions: kms:DeleteCustomKeyStore (IAM policy)  Related operations:     ConnectCustomKeyStore     CreateCustomKeyStore     DescribeCustomKeyStores     DisconnectCustomKeyStore     UpdateCustomKeyStore

    Args:
        custom_key_store_id(str): Enter the ID of the custom key store you want to delete. To find the ID of a custom key store, use the DescribeCustomKeyStores operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.custom_key_store.delete(ctx, custom_key_store_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.custom_key_store.delete custom_key_store_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="delete_custom_key_store",
        op_kwargs={"CustomKeyStoreId": custom_key_store_id},
    )


async def describe_all(
    hub,
    ctx,
    custom_key_store_id: str = None,
    custom_key_store_name: str = None,
    limit: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about custom key stores in the account and Region. This operation is part of the Custom Key Store feature feature in AWS KMS, which combines the convenience and extensive integration of AWS KMS with the isolation and control of a single-tenant key store. By default, this operation returns information about all custom key stores in the account and Region. To get only information about a particular custom key store, use either the CustomKeyStoreName or CustomKeyStoreId parameter (but not both). To determine whether the custom key store is connected to its AWS CloudHSM cluster, use the ConnectionState element in the response. If an attempt to connect the custom key store failed, the ConnectionState value is FAILED and the ConnectionErrorCode element in the response indicates the cause of the failure. For help interpreting the ConnectionErrorCode, see CustomKeyStoresListEntry. Custom key stores have a DISCONNECTED connection state if the key store has never been connected or you use the DisconnectCustomKeyStore operation to disconnect it. If your custom key store state is CONNECTED but you are having trouble using it, make sure that its associated AWS CloudHSM cluster is active and contains the minimum number of HSMs required for the operation, if any.  For help repairing your custom key store, see the Troubleshooting Custom Key Stores topic in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a custom key store in a different AWS account.  Required permissions: kms:DescribeCustomKeyStores (IAM policy)  Related operations:     ConnectCustomKeyStore     CreateCustomKeyStore     DeleteCustomKeyStore     DisconnectCustomKeyStore     UpdateCustomKeyStore

    Args:
        custom_key_store_id(str, optional): Gets only information about the specified custom key store. Enter the key store ID. By default, this operation gets information about all custom key stores in the account and Region. To limit the output to a particular custom key store, you can use either the CustomKeyStoreId or CustomKeyStoreName parameter, but not both. Defaults to None.
        custom_key_store_name(str, optional): Gets only information about the specified custom key store. Enter the friendly name of the custom key store. By default, this operation gets information about all custom key stores in the account and Region. To limit the output to a particular custom key store, you can use either the CustomKeyStoreId or CustomKeyStoreName parameter, but not both. Defaults to None.
        limit(int, optional): Use this parameter to specify the maximum number of items to return. When this value is present, AWS KMS does not return more than the specified number of items, but it might return fewer. Defaults to None.
        marker(str, optional): Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextMarker from the truncated response you just received. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.custom_key_store.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.custom_key_store.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="describe_custom_key_stores",
        op_kwargs={
            "CustomKeyStoreId": custom_key_store_id,
            "CustomKeyStoreName": custom_key_store_name,
            "Limit": limit,
            "Marker": marker,
        },
    )


async def disconnect(hub, ctx, custom_key_store_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disconnects the custom key store from its associated AWS CloudHSM cluster. While a custom key store is disconnected, you can manage the custom key store and its customer master keys (CMKs), but you cannot create or use CMKs in the custom key store. You can reconnect the custom key store at any time.  While a custom key store is disconnected, all attempts to create customer master keys (CMKs) in the custom key store or to use existing CMKs in cryptographic operations will fail. This action can prevent users from storing and accessing sensitive data.   To find the connection state of a custom key store, use the DescribeCustomKeyStores operation. To reconnect a custom key store, use the ConnectCustomKeyStore operation. If the operation succeeds, it returns a JSON object with no properties. This operation is part of the Custom Key Store feature feature in AWS KMS, which combines the convenience and extensive integration of AWS KMS with the isolation and control of a single-tenant key store.  Cross-account use: No. You cannot perform this operation on a custom key store in a different AWS account.  Required permissions: kms:DisconnectCustomKeyStore (IAM policy)  Related operations:     ConnectCustomKeyStore     CreateCustomKeyStore     DeleteCustomKeyStore     DescribeCustomKeyStores     UpdateCustomKeyStore

    Args:
        custom_key_store_id(str): Enter the ID of the custom key store you want to disconnect. To find the ID of a custom key store, use the DescribeCustomKeyStores operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.custom_key_store.disconnect(ctx, custom_key_store_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.custom_key_store.disconnect custom_key_store_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="disconnect_custom_key_store",
        op_kwargs={"CustomKeyStoreId": custom_key_store_id},
    )


async def update(
    hub,
    ctx,
    custom_key_store_id: str,
    new_custom_key_store_name: str = None,
    key_store_password: str = None,
    cloud_hsm_cluster_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the properties of a custom key store. Use the CustomKeyStoreId parameter to identify the custom key store you want to edit. Use the remaining parameters to change the properties of the custom key store. You can only update a custom key store that is disconnected. To disconnect the custom key store, use DisconnectCustomKeyStore. To reconnect the custom key store after the update completes, use ConnectCustomKeyStore. To find the connection state of a custom key store, use the DescribeCustomKeyStores operation. Use the parameters of UpdateCustomKeyStore to edit your keystore settings.   Use the NewCustomKeyStoreName parameter to change the friendly name of the custom key store to the value that you specify.     Use the KeyStorePassword parameter tell AWS KMS the current password of the  kmsuser crypto user (CU) in the associated AWS CloudHSM cluster. You can use this parameter to fix connection failures that occur when AWS KMS cannot log into the associated cluster because the kmsuser password has changed. This value does not change the password in the AWS CloudHSM cluster.     Use the CloudHsmClusterId parameter to associate the custom key store with a different, but related, AWS CloudHSM cluster. You can use this parameter to repair a custom key store if its AWS CloudHSM cluster becomes corrupted or is deleted, or when you need to create or restore a cluster from a backup.    If the operation succeeds, it returns a JSON object with no properties. This operation is part of the Custom Key Store feature feature in AWS KMS, which combines the convenience and extensive integration of AWS KMS with the isolation and control of a single-tenant key store.  Cross-account use: No. You cannot perform this operation on a custom key store in a different AWS account.   Required permissions: kms:UpdateCustomKeyStore (IAM policy)  Related operations:     ConnectCustomKeyStore     CreateCustomKeyStore     DeleteCustomKeyStore     DescribeCustomKeyStores     DisconnectCustomKeyStore

    Args:
        custom_key_store_id(str): Identifies the custom key store that you want to update. Enter the ID of the custom key store. To find the ID of a custom key store, use the DescribeCustomKeyStores operation.
        new_custom_key_store_name(str, optional): Changes the friendly name of the custom key store to the value that you specify. The custom key store name must be unique in the AWS account. Defaults to None.
        key_store_password(str, optional): Enter the current password of the kmsuser crypto user (CU) in the AWS CloudHSM cluster that is associated with the custom key store. This parameter tells AWS KMS the current password of the kmsuser crypto user (CU). It does not set or change the password of any users in the AWS CloudHSM cluster. Defaults to None.
        cloud_hsm_cluster_id(str, optional): Associates the custom key store with a related AWS CloudHSM cluster.  Enter the cluster ID of the cluster that you used to create the custom key store or a cluster that shares a backup history and has the same cluster certificate as the original cluster. You cannot use this parameter to associate a custom key store with an unrelated cluster. In addition, the replacement cluster must fulfill the requirements for a cluster associated with a custom key store. To view the cluster certificate of a cluster, use the DescribeClusters operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.custom_key_store.update(ctx, custom_key_store_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.custom_key_store.update custom_key_store_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="update_custom_key_store",
        op_kwargs={
            "CustomKeyStoreId": custom_key_store_id,
            "NewCustomKeyStoreName": new_custom_key_store_name,
            "KeyStorePassword": key_store_password,
            "CloudHsmClusterId": cloud_hsm_cluster_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def create(hub, ctx, destination_cidr_block: str, vpn_connection_id: str) -> None:
    r"""
    **Autogenerated function**

    Creates a static route associated with a VPN connection between an existing virtual private gateway and a VPN customer gateway. The static route allows traffic to be routed from the virtual private gateway to the VPN customer gateway. For more information, see AWS Site-to-Site VPN in the AWS Site-to-Site VPN User Guide.

    Args:
        destination_cidr_block(str): The CIDR block associated with the local subnet of the customer network.
        vpn_connection_id(str): The ID of the VPN connection.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.connection.route.create(
                ctx, destination_cidr_block=value, vpn_connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.connection.route.create destination_cidr_block=value, vpn_connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_vpn_connection_route",
        op_kwargs={
            "DestinationCidrBlock": destination_cidr_block,
            "VpnConnectionId": vpn_connection_id,
        },
    )


async def delete(hub, ctx, destination_cidr_block: str, vpn_connection_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified static route associated with a VPN connection between an existing virtual private gateway and a VPN customer gateway. The static route allows traffic to be routed from the virtual private gateway to the VPN customer gateway.

    Args:
        destination_cidr_block(str): The CIDR block associated with the local subnet of the customer network.
        vpn_connection_id(str): The ID of the VPN connection.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.connection.route.delete(
                ctx, destination_cidr_block=value, vpn_connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.connection.route.delete destination_cidr_block=value, vpn_connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_vpn_connection_route",
        op_kwargs={
            "DestinationCidrBlock": destination_cidr_block,
            "VpnConnectionId": vpn_connection_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def import_(hub, ctx, source_s3_location: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Ingests application usage data from Amazon Simple Storage Service (Amazon S3). The data must already exist in the S3 location. As part of the action, AWS Application Cost Profiler copies the object from your S3 bucket to an S3 bucket owned by Amazon for processing asynchronously.

    Args:
        source_s3_location(Dict): Amazon S3 location to import application usage data from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.applicationcostprofiler.application_usage.import(ctx, source_s3_location=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.applicationcostprofiler.application_usage.import source_s3_location=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="applicationcostprofiler",
        operation="import_application_usage",
        op_kwargs={"sourceS3Location": source_s3_location},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, task_id: str) -> None:
    r"""
    **Autogenerated function**

    Cancels the specified export task. The task must be in the PENDING or RUNNING state.

    Args:
        task_id(str): The ID of the export task.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.export_task.cancel(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.export_task.cancel task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="cancel_export_task",
        op_kwargs={"taskId": task_id},
    )


async def create(
    hub,
    ctx,
    log_group_name: str,
    from_: int,
    to: int,
    destination: str,
    task_name: str = None,
    log_stream_name_prefix: str = None,
    destination_prefix: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an export task, which allows you to efficiently export data from a log group to an Amazon S3 bucket. When you perform a CreateExportTask operation, you must use credentials that have permission to write to the S3 bucket that you specify as the destination. This is an asynchronous call. If all the required information is provided, this operation initiates an export task and responds with the ID of the task. After the task has started, you can use DescribeExportTasks to get the status of the export task. Each account can only have one active (RUNNING or PENDING) export task at a time. To cancel an export task, use CancelExportTask. You can export logs from multiple log groups or multiple time ranges to the same S3 bucket. To separate out log data for each export task, you can specify a prefix to be used as the Amazon S3 key prefix for all exported objects. Exporting to S3 buckets that are encrypted with AES-256 is supported. Exporting to S3 buckets encrypted with SSE-KMS is not supported.

    Args:
        task_name(str, optional): The name of the export task. Defaults to None.
        log_group_name(str): The name of the log group.
        log_stream_name_prefix(str, optional): Export only log streams that match the provided prefix. If you don't specify a value, no prefix filter is applied. Defaults to None.
        from_(int): The start time of the range for the request, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp earlier than this time are not exported.
        to(int): The end time of the range for the request, expreswatchlogsdocused as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp later than this time are not exported.
        destination(str): The name of S3 bucket for the exported log data. The bucket must be in the same AWS region.
        destination_prefix(str, optional): The prefix used as the start of the key for every object exported. If you don't specify a value, the default is exportedlogs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.export_task.create(
                ctx, log_group_name=value, from_=value, to=value, destination=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.export_task.create log_group_name=value, from_=value, to=value, destination=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="create_export_task",
        op_kwargs={
            "taskName": task_name,
            "logGroupName": log_group_name,
            "logStreamNamePrefix": log_stream_name_prefix,
            "from": from_,
            "to": to,
            "destination": destination,
            "destinationPrefix": destination_prefix,
        },
    )


async def describe_all(
    hub,
    ctx,
    task_id: str = None,
    status_code: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the specified export tasks. You can list all your export tasks or filter the results based on task ID or task status.

    Args:
        task_id(str, optional): The ID of the export task. Specifying a task ID filters the results to zero or one export tasks. Defaults to None.
        status_code(str, optional): The status code of the export task. Specifying a status code filters the results to zero or more export tasks. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of items returned. If you don't specify a value, the default is up to 50 items. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.export_task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.export_task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="describe_export_tasks",
        op_kwargs={
            "taskId": task_id,
            "statusCode": status_code,
            "nextToken": next_token,
            "limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    processing_job_name: str,
    processing_resources: Dict,
    app_specification: Dict,
    role_arn: str,
    processing_inputs: List = None,
    processing_output_config: Dict = None,
    stopping_condition: Dict = None,
    environment: Dict = None,
    network_config: Dict = None,
    tags: List = None,
    experiment_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a processing job.

    Args:
        processing_inputs(List, optional): An array of inputs configuring the data to download into the processing container. Defaults to None.
        processing_output_config(Dict, optional): Output configuration for the processing job. Defaults to None.
        processing_job_name(str):  The name of the processing job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.
        processing_resources(Dict): Identifies the resources, ML compute instances, and ML storage volumes to deploy for a processing job. In distributed training, you specify more than one instance.
        stopping_condition(Dict, optional): The time limit for how long the processing job is allowed to run. Defaults to None.
        app_specification(Dict): Configures the processing job to run a specified Docker container image.
        environment(Dict, optional): The environment variables to set in the Docker container. Up to 100 key and values entries in the map are supported. Defaults to None.
        network_config(Dict, optional): Networking options for a processing job, such as whether to allow inbound and outbound network calls to and from processing containers, and the VPC subnets and security groups to use for VPC-enabled processing jobs. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
        tags(List, optional): (Optional) An array of key-value pairs. For more information, see Using Cost Allocation Tags in the Amazon Web Services Billing and Cost Management User Guide. Defaults to None.
        experiment_config(Dict, optional): Associates a SageMaker job as a trial component with an experiment and trial. Specified when you call the following APIs:    CreateProcessingJob     CreateTrainingJob     CreateTransformJob   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.processing_job.create(
                ctx,
                processing_job_name=value,
                processing_resources=value,
                app_specification=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.processing_job.create processing_job_name=value, processing_resources=value, app_specification=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_processing_job",
        op_kwargs={
            "ProcessingInputs": processing_inputs,
            "ProcessingOutputConfig": processing_output_config,
            "ProcessingJobName": processing_job_name,
            "ProcessingResources": processing_resources,
            "StoppingCondition": stopping_condition,
            "AppSpecification": app_specification,
            "Environment": environment,
            "NetworkConfig": network_config,
            "RoleArn": role_arn,
            "Tags": tags,
            "ExperimentConfig": experiment_config,
        },
    )


async def describe(hub, ctx, processing_job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of a processing job.

    Args:
        processing_job_name(str): The name of the processing job. The name must be unique within an Amazon Web Services Region in the Amazon Web Services account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.processing_job.describe(
                ctx, processing_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.processing_job.describe processing_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_processing_job",
        op_kwargs={"ProcessingJobName": processing_job_name},
    )


async def list_all(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    name_contains: str = None,
    status_equals: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists processing jobs that satisfy various filters.

    Args:
        creation_time_after(str, optional): A filter that returns only processing jobs created after the specified time. Defaults to None.
        creation_time_before(str, optional): A filter that returns only processing jobs created after the specified time. Defaults to None.
        last_modified_time_after(str, optional): A filter that returns only processing jobs modified after the specified time. Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only processing jobs modified before the specified time. Defaults to None.
        name_contains(str, optional): A string in the processing job name. This filter returns only processing jobs whose name contains the specified string. Defaults to None.
        status_equals(str, optional): A filter that retrieves only processing jobs with a specific status. Defaults to None.
        sort_by(str, optional): The field to sort results by. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Ascending. Defaults to None.
        next_token(str, optional): If the result of the previous ListProcessingJobs request was truncated, the response includes a NextToken. To retrieve the next set of processing jobs, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of processing jobs to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.processing_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.processing_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_processing_jobs",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "NameContains": name_contains,
            "StatusEquals": status_equals,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def stop(hub, ctx, processing_job_name: str) -> None:
    r"""
    **Autogenerated function**

    Stops a processing job.

    Args:
        processing_job_name(str): The name of the processing job to stop.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.processing_job.stop(ctx, processing_job_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.processing_job.stop processing_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="stop_processing_job",
        op_kwargs={"ProcessingJobName": processing_job_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the calling account’s home region, if configured. This API is used by other AWS services to determine the regional endpoint for calling AWS Application Discovery Service and Migration Hub. You must call GetHomeRegion at least once before you call any other AWS Application Discovery Service and AWS Migration Hub APIs, to obtain the account's Migration Hub home region.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.migrationhub_config_home_region.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.migrationhub_config_home_region.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="migrationhub-config",
        operation="get_home_region",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, device_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Given a device ID, returns a DescribeDeviceResponse object describing the
     details of the device.

    Args:
        device_id(str): The unique identifier of the device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_device.device.init.describe(ctx, device_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_device.device.init.describe device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="describe_device",
        op_kwargs={"DeviceId": device_id},
    )


async def list_all(
    hub, ctx, device_type: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
       **Autogenerated function**

       Lists the 1-Click compatible devices associated with your AWS account.

       Args:
           device_type(str, optional): The type of the device, such as "button". Defaults to None.
           max_results(int, optional): The maximum number of results to return per request. If not set, a default value of
    100 is used. Defaults to None.
           next_token(str, optional): The token to retrieve the next set of results. Defaults to None.

       Returns:
           Dict

       Examples:
           Call from code:

           .. code-block:: python

               await hub.exec.aws_auto.iot1click_device.device.init.list_all(ctx)

           Call from CLI:

           .. code-block:: bash

               $ idem exec aws_auto.iot1click_device.device.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="list_devices",
        op_kwargs={
            "DeviceType": device_type,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def unclaim(hub, ctx, device_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a device from your AWS account using its device ID.

    Args:
        device_id(str): The unique identifier of the device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_device.device.init.unclaim(ctx, device_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_device.device.init.unclaim device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="unclaim_device",
        op_kwargs={"DeviceId": device_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    rest_api_id: str,
    stage_name: str = None,
    stage_description: str = None,
    description: str = None,
    cache_cluster_enabled: bool = None,
    cache_cluster_size: str = None,
    variables: Dict = None,
    canary_settings: Dict = None,
    tracing_enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Deployment resource, which makes a specified RestApi callable over the internet.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        stage_name(str, optional): The name of the Stage resource for the Deployment resource to create. Defaults to None.
        stage_description(str, optional): The description of the Stage resource for the Deployment resource to create. Defaults to None.
        description(str, optional): The description for the Deployment resource to create. Defaults to None.
        cache_cluster_enabled(bool, optional): Enables a cache cluster for the Stage resource specified in the input. Defaults to None.
        cache_cluster_size(str, optional): Specifies the cache cluster size for the Stage resource specified in the input, if a cache cluster is enabled. Defaults to None.
        variables(Dict, optional): A map that defines the stage variables for the Stage resource that is associated with the new deployment. Variable names can have alphanumeric and underscore characters, and the values must match [A-Za-z0-9-._~:/?#&=,]+. Defaults to None.
        canary_settings(Dict, optional): The input configuration for the canary deployment when the deployment is a canary release deployment. . Defaults to None.
        tracing_enabled(bool, optional): Specifies whether active tracing with X-ray is enabled for the Stage. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.deployment.create(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.deployment.create rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_deployment",
        op_kwargs={
            "restApiId": rest_api_id,
            "stageName": stage_name,
            "stageDescription": stage_description,
            "description": description,
            "cacheClusterEnabled": cache_cluster_enabled,
            "cacheClusterSize": cache_cluster_size,
            "variables": variables,
            "canarySettings": canary_settings,
            "tracingEnabled": tracing_enabled,
        },
    )


async def delete(hub, ctx, rest_api_id: str, deployment_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a Deployment resource. Deleting a deployment will only succeed if there are no Stage resources associated with it.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        deployment_id(str): [Required] The identifier of the Deployment resource to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.deployment.delete(
                ctx, rest_api_id=value, deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.deployment.delete rest_api_id=value, deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_deployment",
        op_kwargs={"restApiId": rest_api_id, "deploymentId": deployment_id},
    )


async def get(
    hub, ctx, rest_api_id: str, deployment_id: str, embed: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a Deployment resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        deployment_id(str): [Required] The identifier of the Deployment resource to get information about.
        embed(List, optional): A query parameter to retrieve the specified embedded resources of the returned Deployment resource in the response. In a REST API call, this embed parameter value is a list of comma-separated strings, as in GET /restapis/{restapi_id}/deployments/{deployment_id}?embed=var1,var2. The SDK and other platform-dependent libraries might use a different format for the list. Currently, this request supports only retrieval of the embedded API summary this way. Hence, the parameter value must be a single-valued list containing only the "apisummary" string. For example, GET /restapis/{restapi_id}/deployments/{deployment_id}?embed=apisummary. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.deployment.get(
                ctx, rest_api_id=value, deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.deployment.get rest_api_id=value, deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_deployment",
        op_kwargs={
            "restApiId": rest_api_id,
            "deploymentId": deployment_id,
            "embed": embed,
        },
    )


async def get_all(
    hub, ctx, rest_api_id: str, position: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a Deployments collection.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.deployment.get_all(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.deployment.get_all rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_deployments",
        op_kwargs={"restApiId": rest_api_id, "position": position, "limit": limit},
    )


async def update(
    hub, ctx, rest_api_id: str, deployment_id: str, patch_operations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about a Deployment resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        deployment_id(str): The replacement identifier for the Deployment resource to change information about.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.deployment.update(
                ctx, rest_api_id=value, deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.deployment.update rest_api_id=value, deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_deployment",
        op_kwargs={
            "restApiId": rest_api_id,
            "deploymentId": deployment_id,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, directory_arn: str, object_reference: Dict, consistency_level: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves metadata about an object.

    Args:
        directory_arn(str): The ARN of the directory being retrieved.
        object_reference(Dict): A reference to the object.
        consistency_level(str, optional): The consistency level at which to retrieve the object information. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.object_.information.get_all(
                ctx, directory_arn=value, object_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.object_.information.get_all directory_arn=value, object_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="get_object_information",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "ObjectReference": object_reference,
            "ConsistencyLevel": consistency_level,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    certificate: str = None,
    domain: str = None,
    endpoint_details: Dict = None,
    endpoint_type: str = None,
    host_key: str = None,
    identity_provider_details: Dict = None,
    identity_provider_type: str = None,
    logging_role: str = None,
    protocols: List = None,
    security_policy_name: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Instantiates an auto-scaling virtual server based on the selected file transfer protocol in Amazon Web Services. When you make updates to your file transfer protocol-enabled server or when you work with users, use the service-generated ServerId property that is assigned to the newly created server.

    Args:
        certificate(str, optional): The Amazon Resource Name (ARN) of the Amazon Web Services Certificate Manager (ACM) certificate. Required when Protocols is set to FTPS. To request a new public certificate, see Request a public certificate in the  Amazon Web Services Certificate Manager User Guide. To import an existing certificate into ACM, see Importing certificates into ACM in the  Amazon Web Services Certificate Manager User Guide. To request a private certificate to use FTPS through private IP addresses, see Request a private certificate in the  Amazon Web Services Certificate Manager User Guide. Certificates with the following cryptographic algorithms and key sizes are supported:   2048-bit RSA (RSA_2048)   4096-bit RSA (RSA_4096)   Elliptic Prime Curve 256 bit (EC_prime256v1)   Elliptic Prime Curve 384 bit (EC_secp384r1)   Elliptic Prime Curve 521 bit (EC_secp521r1)    The certificate must be a valid SSL/TLS X.509 version 3 certificate with FQDN or IP address specified and information about the issuer. . Defaults to None.
        domain(str, optional): The domain of the storage system that is used for file transfers. There are two domains available: Amazon Simple Storage Service (Amazon S3) and Amazon Elastic File System (Amazon EFS). The default value is S3.  After the server is created, the domain cannot be changed. . Defaults to None.
        endpoint_details(Dict, optional): The virtual private cloud (VPC) endpoint settings that are configured for your server. When you host your endpoint within your VPC, you can make it accessible only to resources within your VPC, or you can attach Elastic IP addresses and make it accessible to clients over the internet. Your VPC's default security groups are automatically assigned to your endpoint. Defaults to None.
        endpoint_type(str, optional): The type of endpoint that you want your server to use. You can choose to make your server's endpoint publicly accessible (PUBLIC) or host it inside your VPC. With an endpoint that is hosted in a VPC, you can restrict access to your server and resources only within your VPC or choose to make it internet facing by attaching Elastic IP addresses directly to it.   After May 19, 2021, you won't be able to create a server using EndpointType=VPC_ENDPOINT in your Amazon Web Services account if your account hasn't already done so before May 19, 2021. If you have already created servers with EndpointType=VPC_ENDPOINT in your Amazon Web Services account on or before May 19, 2021, you will not be affected. After this date, use EndpointType=VPC. For more information, see https://docs.aws.amazon.com/transfer/latest/userguide/create-server-in-vpc.html#deprecate-vpc-endpoint. It is recommended that you use VPC as the EndpointType. With this endpoint type, you have the option to directly associate up to three Elastic IPv4 addresses (BYO IP included) with your server's endpoint and use VPC security groups to restrict traffic by the client's public IP address. This is not possible with EndpointType set to VPC_ENDPOINT. . Defaults to None.
        host_key(str, optional): The RSA private key as generated by the ssh-keygen -N "" -m PEM -f my-new-server-key command.  If you aren't planning to migrate existing users from an existing SFTP-enabled server to a new server, don't update the host key. Accidentally changing a server's host key can be disruptive.  For more information, see Change the host key for your SFTP-enabled server in the Amazon Web Services Transfer Family User Guide. Defaults to None.
        identity_provider_details(Dict, optional): Required when IdentityProviderType is set to AWS_DIRECTORY_SERVICE or API_GATEWAY. Accepts an array containing all of the information required to use a directory in AWS_DIRECTORY_SERVICE or invoke a customer-supplied authentication API, including the API Gateway URL. Not required when IdentityProviderType is set to SERVICE_MANAGED. Defaults to None.
        identity_provider_type(str, optional): Specifies the mode of authentication for a server. The default value is SERVICE_MANAGED, which allows you to store and access user credentials within the Amazon Web Services Transfer Family service. Use AWS_DIRECTORY_SERVICE to provide access to Active Directory groups in Amazon Web Services Managed Active Directory or Microsoft Active Directory in your on-premises environment or in Amazon Web Services using AD Connectors. This option also requires you to provide a Directory ID using the IdentityProviderDetails parameter. Use the API_GATEWAY value to integrate with an identity provider of your choosing. The API_GATEWAY setting requires you to provide an API Gateway endpoint URL to call for authentication using the IdentityProviderDetails parameter. Defaults to None.
        logging_role(str, optional): Specifies the Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that allows a server to turn on Amazon CloudWatch logging for Amazon S3 or Amazon EFS events. When set, user activity can be viewed in your CloudWatch logs. Defaults to None.
        protocols(List, optional): Specifies the file transfer protocol or protocols over which your file transfer protocol client can connect to your server's endpoint. The available protocols are:    SFTP (Secure Shell (SSH) File Transfer Protocol): File transfer over SSH    FTPS (File Transfer Protocol Secure): File transfer with TLS encryption    FTP (File Transfer Protocol): Unencrypted file transfer    If you select FTPS, you must choose a certificate stored in Amazon Web Services Certificate Manager (ACM) which is used to identify your server when clients connect to it over FTPS. If Protocol includes either FTP or FTPS, then the EndpointType must be VPC and the IdentityProviderType must be AWS_DIRECTORY_SERVICE or API_GATEWAY. If Protocol includes FTP, then AddressAllocationIds cannot be associated. If Protocol is set only to SFTP, the EndpointType can be set to PUBLIC and the IdentityProviderType can be set to SERVICE_MANAGED. . Defaults to None.
        security_policy_name(str, optional): Specifies the name of the security policy that is attached to the server. Defaults to None.
        tags(List, optional): Key-value pairs that can be used to group and search for servers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.server.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.server.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="create_server",
        op_kwargs={
            "Certificate": certificate,
            "Domain": domain,
            "EndpointDetails": endpoint_details,
            "EndpointType": endpoint_type,
            "HostKey": host_key,
            "IdentityProviderDetails": identity_provider_details,
            "IdentityProviderType": identity_provider_type,
            "LoggingRole": logging_role,
            "Protocols": protocols,
            "SecurityPolicyName": security_policy_name,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, server_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the file transfer protocol-enabled server that you specify. No response returns from this operation.

    Args:
        server_id(str): A unique system-assigned identifier for a server instance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.server.delete(ctx, server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.server.delete server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="delete_server",
        op_kwargs={"ServerId": server_id},
    )


async def describe(hub, ctx, server_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a file transfer protocol-enabled server that you specify by passing the ServerId parameter. The response contains a description of a server's properties. When you set EndpointType to VPC, the response will contain the EndpointDetails.

    Args:
        server_id(str): A system-assigned unique identifier for a server.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.server.describe(ctx, server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.server.describe server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="describe_server",
        op_kwargs={"ServerId": server_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the file transfer protocol-enabled servers that are associated with your Amazon Web Services account.

    Args:
        max_results(int, optional): Specifies the number of servers to return as a response to the ListServers query. Defaults to None.
        next_token(str, optional): When additional results are obtained from the ListServers command, a NextToken parameter is returned in the output. You can then pass the NextToken parameter in a subsequent command to continue listing additional servers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.server.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.server.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="list_servers",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def start(hub, ctx, server_id: str) -> None:
    r"""
    **Autogenerated function**

    Changes the state of a file transfer protocol-enabled server from OFFLINE to ONLINE. It has no impact on a server that is already ONLINE. An ONLINE server can accept and process file transfer jobs. The state of STARTING indicates that the server is in an intermediate state, either not fully able to respond, or not fully online. The values of START_FAILED can indicate an error condition. No response is returned from this call.

    Args:
        server_id(str): A system-assigned unique identifier for a server that you start.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.server.start(ctx, server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.server.start server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="start_server",
        op_kwargs={"ServerId": server_id},
    )


async def stop(hub, ctx, server_id: str) -> None:
    r"""
    **Autogenerated function**

    Changes the state of a file transfer protocol-enabled server from ONLINE to OFFLINE. An OFFLINE server cannot accept and process file transfer jobs. Information tied to your server, such as server and user properties, are not affected by stopping your server.  Stopping the server will not reduce or impact your file transfer protocol endpoint billing; you must delete the server to stop being billed.  The state of STOPPING indicates that the server is in an intermediate state, either not fully able to respond, or not fully offline. The values of STOP_FAILED can indicate an error condition. No response is returned from this call.

    Args:
        server_id(str): A system-assigned unique identifier for a server that you stopped.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.server.stop(ctx, server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.server.stop server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="stop_server",
        op_kwargs={"ServerId": server_id},
    )


async def update(
    hub,
    ctx,
    server_id: str,
    certificate: str = None,
    protocol_details: Dict = None,
    endpoint_details: Dict = None,
    endpoint_type: str = None,
    host_key: str = None,
    identity_provider_details: Dict = None,
    logging_role: str = None,
    protocols: List = None,
    security_policy_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the file transfer protocol-enabled server's properties after that server has been created. The UpdateServer call returns the ServerId of the server you updated.

    Args:
        certificate(str, optional): The Amazon Resource Name (ARN) of the Amazon Web ServicesCertificate Manager (ACM) certificate. Required when Protocols is set to FTPS. To request a new public certificate, see Request a public certificate in the  Amazon Web ServicesCertificate Manager User Guide. To import an existing certificate into ACM, see Importing certificates into ACM in the  Amazon Web ServicesCertificate Manager User Guide. To request a private certificate to use FTPS through private IP addresses, see Request a private certificate in the  Amazon Web ServicesCertificate Manager User Guide. Certificates with the following cryptographic algorithms and key sizes are supported:   2048-bit RSA (RSA_2048)   4096-bit RSA (RSA_4096)   Elliptic Prime Curve 256 bit (EC_prime256v1)   Elliptic Prime Curve 384 bit (EC_secp384r1)   Elliptic Prime Curve 521 bit (EC_secp521r1)    The certificate must be a valid SSL/TLS X.509 version 3 certificate with FQDN or IP address specified and information about the issuer. . Defaults to None.
        protocol_details(Dict, optional):  The protocol settings that are configured for your server.   Use the PassiveIp parameter to indicate passive mode (for FTP and FTPS protocols). Enter a single dotted-quad IPv4 address, such as the external IP address of a firewall, router, or load balancer. . Defaults to None.
        endpoint_details(Dict, optional): The virtual private cloud (VPC) endpoint settings that are configured for your server. When you host your endpoint within your VPC, you can make it accessible only to resources within your VPC, or you can attach Elastic IP addresses and make it accessible to clients over the internet. Your VPC's default security groups are automatically assigned to your endpoint. Defaults to None.
        endpoint_type(str, optional): The type of endpoint that you want your server to use. You can choose to make your server's endpoint publicly accessible (PUBLIC) or host it inside your VPC. With an endpoint that is hosted in a VPC, you can restrict access to your server and resources only within your VPC or choose to make it internet facing by attaching Elastic IP addresses directly to it.   After May 19, 2021, you won't be able to create a server using EndpointType=VPC_ENDPOINT in your Amazon Web Servicesaccount if your account hasn't already done so before May 19, 2021. If you have already created servers with EndpointType=VPC_ENDPOINT in your Amazon Web Servicesaccount on or before May 19, 2021, you will not be affected. After this date, use EndpointType=VPC. For more information, see https://docs.aws.amazon.com/transfer/latest/userguide/create-server-in-vpc.html#deprecate-vpc-endpoint. It is recommended that you use VPC as the EndpointType. With this endpoint type, you have the option to directly associate up to three Elastic IPv4 addresses (BYO IP included) with your server's endpoint and use VPC security groups to restrict traffic by the client's public IP address. This is not possible with EndpointType set to VPC_ENDPOINT. . Defaults to None.
        host_key(str, optional): The RSA private key as generated by ssh-keygen -N "" -m PEM -f my-new-server-key.  If you aren't planning to migrate existing users from an existing server to a new server, don't update the host key. Accidentally changing a server's host key can be disruptive.  For more information, see Change the host key for your SFTP-enabled server in the Amazon Web ServicesTransfer Family User Guide. Defaults to None.
        identity_provider_details(Dict, optional): An array containing all of the information required to call a customer's authentication API method. Defaults to None.
        logging_role(str, optional): Specifies the Amazon Resource Name (ARN) of the Amazon Web Services Identity and Access Management (IAM) role that allows a server to turn on Amazon CloudWatch logging for Amazon S3 or Amazon EFS events. When set, user activity can be viewed in your CloudWatch logs. Defaults to None.
        protocols(List, optional): Specifies the file transfer protocol or protocols over which your file transfer protocol client can connect to your server's endpoint. The available protocols are:   Secure Shell (SSH) File Transfer Protocol (SFTP): File transfer over SSH   File Transfer Protocol Secure (FTPS): File transfer with TLS encryption   File Transfer Protocol (FTP): Unencrypted file transfer    If you select FTPS, you must choose a certificate stored in Amazon Web ServicesCertificate Manager (ACM) which will be used to identify your server when clients connect to it over FTPS. If Protocol includes either FTP or FTPS, then the EndpointType must be VPC and the IdentityProviderType must be AWS_DIRECTORY_SERVICE or API_GATEWAY. If Protocol includes FTP, then AddressAllocationIds cannot be associated. If Protocol is set only to SFTP, the EndpointType can be set to PUBLIC and the IdentityProviderType can be set to SERVICE_MANAGED. . Defaults to None.
        security_policy_name(str, optional): Specifies the name of the security policy that is attached to the server. Defaults to None.
        server_id(str): A system-assigned unique identifier for a server instance that the user account is assigned to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.server.update(ctx, server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.server.update server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="update_server",
        op_kwargs={
            "Certificate": certificate,
            "ProtocolDetails": protocol_details,
            "EndpointDetails": endpoint_details,
            "EndpointType": endpoint_type,
            "HostKey": host_key,
            "IdentityProviderDetails": identity_provider_details,
            "LoggingRole": logging_role,
            "Protocols": protocols,
            "SecurityPolicyName": security_policy_name,
            "ServerId": server_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    report_generator_name: str,
    type_: List,
    report_context: Dict,
    report_frequency: Dict,
    client_token: str,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new report generator.

    Args:
        report_generator_name(str): Name of the report generator.
        type_(List): Type of reports to generate. The following report types an be generated:   License configuration report - Reports on the number and details of consumed licenses for a license configuration.   Resource report - Reports on the tracked licenses and resource consumption for a license configuration.  .
        report_context(Dict): Defines the type of license configuration the report generator tracks.
        report_frequency(Dict): Frequency by which reports are generated. Reports can be generated daily, monthly, or weekly.
        client_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
        description(str, optional): Description of the report generator. Defaults to None.
        tags(List, optional): Tags to add to the report generator. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.manager_report_generator.create(
                ctx,
                report_generator_name=value,
                type_=value,
                report_context=value,
                report_frequency=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.manager_report_generator.create report_generator_name=value, type_=value, report_context=value, report_frequency=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="create_license_manager_report_generator",
        op_kwargs={
            "ReportGeneratorName": report_generator_name,
            "Type": type_,
            "ReportContext": report_context,
            "ReportFrequency": report_frequency,
            "ClientToken": client_token,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, license_manager_report_generator_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete an existing report generator. This action deletes the report generator, which stops it from generating future reports and cannot be reversed. However, the previous reports from this generator will remain in your S3 bucket.

    Args:
        license_manager_report_generator_arn(str): Amazon Resource Number (ARN) of the report generator that will be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.manager_report_generator.delete(
                ctx, license_manager_report_generator_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.manager_report_generator.delete license_manager_report_generator_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="delete_license_manager_report_generator",
        op_kwargs={
            "LicenseManagerReportGeneratorArn": license_manager_report_generator_arn
        },
    )


async def get(hub, ctx, license_manager_report_generator_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information on the specified report generator.

    Args:
        license_manager_report_generator_arn(str): mazon Resource Number (ARN) of the report generator to retrieve information on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.manager_report_generator.get(
                ctx, license_manager_report_generator_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.manager_report_generator.get license_manager_report_generator_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="get_license_manager_report_generator",
        op_kwargs={
            "LicenseManagerReportGeneratorArn": license_manager_report_generator_arn
        },
    )


async def list_all(
    hub, ctx, filters: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the report generators for your account.

    Args:
        filters(List, optional): Filters to scope the results. The following filters are supported:     LicenseConfigurationArn   . Defaults to None.
        next_token(str, optional): Token for the next set of results. Defaults to None.
        max_results(int, optional): Maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.manager_report_generator.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.manager_report_generator.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="list_license_manager_report_generators",
        op_kwargs={
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    license_manager_report_generator_arn: str,
    report_generator_name: str,
    type_: List,
    report_context: Dict,
    report_frequency: Dict,
    client_token: str,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a report generator. After you make changes to a report generator, it will start generating new reports within 60 minutes of being updated.

    Args:
        license_manager_report_generator_arn(str): Amazon Resource Number (ARN) of the report generator to update.
        report_generator_name(str): Name of the report generator.
        type_(List): Type of reports to generate. The following report types an be generated:   License configuration report - Reports on the number and details of consumed licenses for a license configuration.   Resource report - Reports on the tracked licenses and resource consumption for a license configuration.  .
        report_context(Dict): ?.
        report_frequency(Dict): Frequency by which reports are generated. The following options are avaiable: ??? What are the APi value options?.
        client_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
        description(str, optional): Description of the report generator. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.manager_report_generator.update(
                ctx,
                license_manager_report_generator_arn=value,
                report_generator_name=value,
                type_=value,
                report_context=value,
                report_frequency=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.manager_report_generator.update license_manager_report_generator_arn=value, report_generator_name=value, type_=value, report_context=value, report_frequency=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="update_license_manager_report_generator",
        op_kwargs={
            "LicenseManagerReportGeneratorArn": license_manager_report_generator_arn,
            "ReportGeneratorName": report_generator_name,
            "Type": type_,
            "ReportContext": report_context,
            "ReportFrequency": report_frequency,
            "ClientToken": client_token,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def post(
    hub, ctx, in_reply_to: str, content: str, client_request_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Posts a comment in reply to an existing comment on a comparison between commits or a pull request.

    Args:
        in_reply_to(str): The system-generated ID of the comment to which you want to reply. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.
        client_request_token(str, optional): A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token. Defaults to None.
        content(str): The contents of your reply to a comment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.comment.reply.post(
                ctx, in_reply_to=value, content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.comment.reply.post in_reply_to=value, content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="post_comment_reply",
        op_kwargs={
            "inReplyTo": in_reply_to,
            "clientRequestToken": client_request_token,
            "content": content,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(
    hub,
    ctx,
    directory_arn: str,
    source_object_reference: Dict,
    target_object_reference: Dict,
    typed_link_facet: Dict,
    attributes: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Attaches a typed link to a specified source and target object. For more information, see Typed Links.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) of the directory where you want to attach the typed link.
        source_object_reference(Dict): Identifies the source object that the typed link will attach to.
        target_object_reference(Dict): Identifies the target object that the typed link will attach to.
        typed_link_facet(Dict): Identifies the typed link facet that is associated with the typed link.
        attributes(List): A set of attributes that are associated with the typed link.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.typed_link.init.attach(
                ctx,
                directory_arn=value,
                source_object_reference=value,
                target_object_reference=value,
                typed_link_facet=value,
                attributes=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.typed_link.init.attach directory_arn=value, source_object_reference=value, target_object_reference=value, typed_link_facet=value, attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="attach_typed_link",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "SourceObjectReference": source_object_reference,
            "TargetObjectReference": target_object_reference,
            "TypedLinkFacet": typed_link_facet,
            "Attributes": attributes,
        },
    )


async def detach(hub, ctx, directory_arn: str, typed_link_specifier: Dict) -> None:
    r"""
    **Autogenerated function**

    Detaches a typed link from a specified source and target object. For more information, see Typed Links.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) of the directory where you want to detach the typed link.
        typed_link_specifier(Dict): Used to accept a typed link specifier as input.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.typed_link.init.detach(
                ctx, directory_arn=value, typed_link_specifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.typed_link.init.detach directory_arn=value, typed_link_specifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="detach_typed_link",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "TypedLinkSpecifier": typed_link_specifier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    flow_name: str,
    trigger_config: Dict,
    source_flow_config: Dict,
    destination_flow_config_list: List,
    tasks: List,
    description: str = None,
    kms_arn: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Enables your application to create a new flow using Amazon AppFlow. You must create a connector profile before calling this API. Please note that the Request Syntax below shows syntax for multiple destinations, however, you can only transfer data to one item in this list at a time. Amazon AppFlow does not currently support flows to multiple destinations at once.

    Args:
        flow_name(str):  The specified name of the flow. Spaces are not allowed. Use underscores (_) or hyphens (-) only. .
        description(str, optional):  A description of the flow you want to create. . Defaults to None.
        kms_arn(str, optional):  The ARN (Amazon Resource Name) of the Key Management Service (KMS) key you provide for encryption. This is required if you do not want to use the Amazon AppFlow-managed KMS key. If you don't provide anything here, Amazon AppFlow uses the Amazon AppFlow-managed KMS key. . Defaults to None.
        trigger_config(Dict):  The trigger settings that determine how and when the flow runs. .
        source_flow_config(Dict):  The configuration that controls how Amazon AppFlow retrieves data from the source connector. .
        destination_flow_config_list(List):  The configuration that controls how Amazon AppFlow places data in the destination connector. .
        tasks(List):  A list of tasks that Amazon AppFlow performs while transferring the data in the flow run. .
        tags(Dict, optional):  The tags used to organize, track, or control access for your flow. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.flow.init.create(
                ctx,
                flow_name=value,
                trigger_config=value,
                source_flow_config=value,
                destination_flow_config_list=value,
                tasks=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.flow.init.create flow_name=value, trigger_config=value, source_flow_config=value, destination_flow_config_list=value, tasks=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="create_flow",
        op_kwargs={
            "flowName": flow_name,
            "description": description,
            "kmsArn": kms_arn,
            "triggerConfig": trigger_config,
            "sourceFlowConfig": source_flow_config,
            "destinationFlowConfigList": destination_flow_config_list,
            "tasks": tasks,
            "tags": tags,
        },
    )


async def delete(hub, ctx, flow_name: str, force_delete: bool = None) -> Dict:
    r"""
    **Autogenerated function**

     Enables your application to delete an existing flow. Before deleting the flow, Amazon AppFlow validates the request by checking the flow configuration and status. You can delete flows one at a time.

    Args:
        flow_name(str):  The specified name of the flow. Spaces are not allowed. Use underscores (_) or hyphens (-) only. .
        force_delete(bool, optional):  Indicates whether Amazon AppFlow should delete the flow, even if it is currently in use. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.flow.init.delete(ctx, flow_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.flow.init.delete flow_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="delete_flow",
        op_kwargs={"flowName": flow_name, "forceDelete": force_delete},
    )


async def describe(hub, ctx, flow_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Provides a description of the specified flow.

    Args:
        flow_name(str):  The specified name of the flow. Spaces are not allowed. Use underscores (_) or hyphens (-) only. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.flow.init.describe(ctx, flow_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.flow.init.describe flow_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="describe_flow",
        op_kwargs={"flowName": flow_name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Lists all of the flows associated with your account.

    Args:
        max_results(int, optional):  Specifies the maximum number of items that should be returned in the result set. . Defaults to None.
        next_token(str, optional):  The pagination token for next page of data. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.flow.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.flow.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="list_flows",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def start(hub, ctx, flow_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Activates an existing flow. For on-demand flows, this operation runs the flow immediately. For schedule and event-triggered flows, this operation activates the flow.

    Args:
        flow_name(str):  The specified name of the flow. Spaces are not allowed. Use underscores (_) or hyphens (-) only. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.flow.init.start(ctx, flow_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.flow.init.start flow_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="start_flow",
        op_kwargs={"flowName": flow_name},
    )


async def stop(hub, ctx, flow_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Deactivates the existing flow. For on-demand flows, this operation returns an unsupportedOperationException error message. For schedule and event-triggered flows, this operation deactivates the flow.

    Args:
        flow_name(str):  The specified name of the flow. Spaces are not allowed. Use underscores (_) or hyphens (-) only. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.flow.init.stop(ctx, flow_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.flow.init.stop flow_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="stop_flow",
        op_kwargs={"flowName": flow_name},
    )


async def update(
    hub,
    ctx,
    flow_name: str,
    trigger_config: Dict,
    destination_flow_config_list: List,
    tasks: List,
    description: str = None,
    source_flow_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates an existing flow.

    Args:
        flow_name(str):  The specified name of the flow. Spaces are not allowed. Use underscores (_) or hyphens (-) only. .
        description(str, optional):  A description of the flow. . Defaults to None.
        trigger_config(Dict):  The trigger settings that determine how and when the flow runs. .
        source_flow_config(Dict, optional):  Contains information about the configuration of the source connector used in the flow. . Defaults to None.
        destination_flow_config_list(List):  The configuration that controls how Amazon AppFlow transfers data to the destination connector. .
        tasks(List):  A list of tasks that Amazon AppFlow performs while transferring the data in the flow run. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.flow.init.update(
                ctx,
                flow_name=value,
                trigger_config=value,
                destination_flow_config_list=value,
                tasks=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.flow.init.update flow_name=value, trigger_config=value, destination_flow_config_list=value, tasks=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="update_flow",
        op_kwargs={
            "flowName": flow_name,
            "description": description,
            "triggerConfig": trigger_config,
            "sourceFlowConfig": source_flow_config,
            "destinationFlowConfigList": destination_flow_config_list,
            "tasks": tasks,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    repository_name: str,
    after_commit_specifier: str,
    before_commit_specifier: str = None,
    before_path: str = None,
    after_path: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the differences in a valid commit specifier (such as a branch, tag, HEAD, commit ID, or other fully qualified reference). Results can be limited to a specified path.

    Args:
        repository_name(str): The name of the repository where you want to get differences.
        before_commit_specifier(str, optional): The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, the full commit ID). Optional. If not specified, all changes before the afterCommitSpecifier value are shown. If you do not use beforeCommitSpecifier in your request, consider limiting the results with maxResults. Defaults to None.
        after_commit_specifier(str): The branch, tag, HEAD, or other fully qualified reference used to identify a commit.
        before_path(str, optional): The file path in which to check for differences. Limits the results to this path. Can also be used to specify the previous name of a directory or folder. If beforePath and afterPath are not specified, differences are shown for all paths. Defaults to None.
        after_path(str, optional): The file path in which to check differences. Limits the results to this path. Can also be used to specify the changed name of a directory or folder, if it has changed. If not specified, differences are shown for all paths. Defaults to None.
        max_results(int, optional): A non-zero, non-negative integer used to limit the number of returned results. Defaults to None.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.difference.get_all(
                ctx, repository_name=value, after_commit_specifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.difference.get_all repository_name=value, after_commit_specifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_differences",
        op_kwargs={
            "repositoryName": repository_name,
            "beforeCommitSpecifier": before_commit_specifier,
            "afterCommitSpecifier": after_commit_specifier,
            "beforePath": before_path,
            "afterPath": after_path,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, dbi_resource_id: str = None, db_instance_automated_backups_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes automated backups using the DbiResourceId value of the source DB instance or the Amazon Resource Name (ARN) of the automated backups.

    Args:
        dbi_resource_id(str, optional): The identifier for the source DB instance, which can't be changed and which is unique to an Amazon Web Services Region. Defaults to None.
        db_instance_automated_backups_arn(str, optional): The Amazon Resource Name (ARN) of the automated backups to delete, for example, arn:aws:rds:us-east-1:123456789012:auto-backup:ab-L2IJCEXJP7XQ7HOJ4SIEXAMPLE. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.instance.automated_backup.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.instance.automated_backup.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_db_instance_automated_backup",
        op_kwargs={
            "DbiResourceId": dbi_resource_id,
            "DBInstanceAutomatedBackupsArn": db_instance_automated_backups_arn,
        },
    )


async def describe_all(
    hub,
    ctx,
    dbi_resource_id: str = None,
    db_instance_identifier: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
    db_instance_automated_backups_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Displays backups for both current and deleted instances. For example, use this operation to find details about automated backups for previously deleted instances. Current instances with retention periods greater than zero (0) are returned for both the DescribeDBInstanceAutomatedBackups and DescribeDBInstances operations. All parameters are optional.

    Args:
        dbi_resource_id(str, optional): The resource ID of the DB instance that is the source of the automated backup. This parameter isn't case-sensitive. . Defaults to None.
        db_instance_identifier(str, optional): (Optional) The user-supplied instance identifier. If this parameter is specified, it must match the identifier of an existing DB instance. It returns information from the specific DB instance' automated backup. This parameter isn't case-sensitive. . Defaults to None.
        filters(List, optional): A filter that specifies which resources to return based on status. Supported filters are the following:    status     active - automated backups for current instances    retained - automated backups for deleted instances and after backup replication is stopped    creating - automated backups that are waiting for the first automated snapshot to be available      db-instance-id - Accepts DB instance identifiers and Amazon Resource Names (ARNs). The results list includes only information about the DB instance automated backups identified by these ARNs.    dbi-resource-id - Accepts DB resource identifiers and Amazon Resource Names (ARNs). The results list includes only information about the DB instance resources identified by these ARNs.   Returns all resources by default. The status for each resource is specified in the response. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results. Defaults to None.
        marker(str, optional): The pagination token provided in the previous request. If this parameter is specified the response includes only records beyond the marker, up to MaxRecords. Defaults to None.
        db_instance_automated_backups_arn(str, optional): The Amazon Resource Name (ARN) of the replicated automated backups, for example, arn:aws:rds:us-east-1:123456789012:auto-backup:ab-L2IJCEXJP7XQ7HOJ4SIEXAMPLE. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.instance.automated_backup.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.instance.automated_backup.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_instance_automated_backups",
        op_kwargs={
            "DbiResourceId": dbi_resource_id,
            "DBInstanceIdentifier": db_instance_identifier,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
            "DBInstanceAutomatedBackupsArn": db_instance_automated_backups_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, detector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the account selected as the delegated administrator for GuardDuty.

    Args:
        detector_id(str): The ID of the detector to retrieve information about the delegated administrator from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.organization.configuration.describe(
                ctx, detector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.organization.configuration.describe detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="describe_organization_configuration",
        op_kwargs={"DetectorId": detector_id},
    )


async def update(
    hub, ctx, detector_id: str, auto_enable: bool, data_sources: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the delegated administrator account with the values provided.

    Args:
        detector_id(str): The ID of the detector to update the delegated administrator for.
        auto_enable(bool): Indicates whether to automatically enable member accounts in the organization.
        data_sources(Dict, optional): Describes which data sources will be updated. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.organization.configuration.update(
                ctx, detector_id=value, auto_enable=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.organization.configuration.update detector_id=value, auto_enable=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="update_organization_configuration",
        op_kwargs={
            "DetectorId": detector_id,
            "AutoEnable": auto_enable,
            "DataSources": data_sources,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    domain_name: str,
    rest_api_id: str,
    base_path: str = None,
    stage: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new BasePathMapping resource.

    Args:
        domain_name(str): [Required] The domain name of the BasePathMapping resource to create.
        base_path(str, optional): The base path name that callers of the API must provide as part of the URL after the domain name. This value must be unique for all of the mappings across a single API. Specify '(none)' if you do not want callers to specify a base path name after the domain name. Defaults to None.
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        stage(str, optional): The name of the API's stage that you want to use for this mapping. Specify '(none)' if you want callers to explicitly specify the stage name after any base path name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.base_path_mapping.create(
                ctx, domain_name=value, rest_api_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.base_path_mapping.create domain_name=value, rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_base_path_mapping",
        op_kwargs={
            "domainName": domain_name,
            "basePath": base_path,
            "restApiId": rest_api_id,
            "stage": stage,
        },
    )


async def delete(hub, ctx, domain_name: str, base_path: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the BasePathMapping resource.

    Args:
        domain_name(str): [Required] The domain name of the BasePathMapping resource to delete.
        base_path(str): [Required] The base path name of the BasePathMapping resource to delete. To specify an empty base path, set this parameter to '(none)'.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.base_path_mapping.delete(
                ctx, domain_name=value, base_path=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.base_path_mapping.delete domain_name=value, base_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_base_path_mapping",
        op_kwargs={"domainName": domain_name, "basePath": base_path},
    )


async def get(hub, ctx, domain_name: str, base_path: str) -> Dict:
    r"""
    **Autogenerated function**

    Describe a BasePathMapping resource.

    Args:
        domain_name(str): [Required] The domain name of the BasePathMapping resource to be described.
        base_path(str): [Required] The base path name that callers of the API must provide as part of the URL after the domain name. This value must be unique for all of the mappings across a single API. Specify '(none)' if you do not want callers to specify any base path name after the domain name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.base_path_mapping.get(
                ctx, domain_name=value, base_path=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.base_path_mapping.get domain_name=value, base_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_base_path_mapping",
        op_kwargs={"domainName": domain_name, "basePath": base_path},
    )


async def get_all(
    hub, ctx, domain_name: str, position: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Represents a collection of BasePathMapping resources.

    Args:
        domain_name(str): [Required] The domain name of a BasePathMapping resource.
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.base_path_mapping.get_all(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.base_path_mapping.get_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_base_path_mappings",
        op_kwargs={"domainName": domain_name, "position": position, "limit": limit},
    )


async def update(
    hub, ctx, domain_name: str, base_path: str, patch_operations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about the BasePathMapping resource.

    Args:
        domain_name(str): [Required] The domain name of the BasePathMapping resource to change.
        base_path(str): [Required] The base path of the BasePathMapping resource to change. To specify an empty base path, set this parameter to '(none)'.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.base_path_mapping.update(
                ctx, domain_name=value, base_path=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.base_path_mapping.update domain_name=value, base_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_base_path_mapping",
        op_kwargs={
            "domainName": domain_name,
            "basePath": base_path,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    service_type: str,
    identifier: str,
    metric_queries: List,
    start_time: str,
    end_time: str,
    period_in_seconds: int = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve Performance Insights metrics for a set of data sources, over a time period. You can provide specific dimension groups and dimensions, and provide aggregation and filtering criteria for each group.  Each response element returns a maximum of 500 bytes. For larger elements, such as SQL statements, only the first 500 bytes are returned.

    Args:
        service_type(str): The AWS service for which Performance Insights returns metrics. The only valid value for ServiceType is RDS.
        identifier(str): An immutable, AWS Region-unique identifier for a data source. Performance Insights gathers metrics from this data source. To use a DB instance as a data source, specify its DbiResourceId value. For example, specify db-FAIHNTYBKTGAUSUZQYPDS2GW4A.
        metric_queries(List): An array of one or more queries to perform. Each query must specify a Performance Insights metric, and can optionally specify aggregation and filtering criteria.
        start_time(str): The date and time specifying the beginning of the requested time series data. You can't specify a StartTime that's earlier than 7 days ago. The value specified is inclusive - data points equal to or greater than StartTime will be returned. The value for StartTime must be earlier than the value for EndTime.
        end_time(str): The date and time specifying the end of the requested time series data. The value specified is exclusive - data points less than (but not equal to) EndTime will be returned. The value for EndTime must be later than the value for StartTime.
        period_in_seconds(int, optional): The granularity, in seconds, of the data points returned from Performance Insights. A period can be as short as one second, or as long as one day (86400 seconds). Valid values are:    1 (one second)    60 (one minute)    300 (five minutes)    3600 (one hour)    86400 (twenty-four hours)   If you don't specify PeriodInSeconds, then Performance Insights will choose a value for you, with a goal of returning roughly 100-200 data points in the response. Defaults to None.
        max_results(int, optional): The maximum number of items to return in the response. If more items exist than the specified MaxRecords value, a pagination token is included in the response so that the remaining results can be retrieved. . Defaults to None.
        next_token(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the token, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pi.resource_metric.get_all(
                ctx,
                service_type=value,
                identifier=value,
                metric_queries=value,
                start_time=value,
                end_time=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pi.resource_metric.get_all service_type=value, identifier=value, metric_queries=value, start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pi",
        operation="get_resource_metrics",
        op_kwargs={
            "ServiceType": service_type,
            "Identifier": identifier,
            "MetricQueries": metric_queries,
            "StartTime": start_time,
            "EndTime": end_time,
            "PeriodInSeconds": period_in_seconds,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )
